camelot.camelot.view.workspace

Package camelot :: Package camelot :: Package view :: Module workspace |
[hide private]
[frames] | no frames]

# Module workspace

source code

This module provides a singleton workspace that can be used by views and widget to create new windows or raise existing ones

Classes | [hide private]
| DesktopWorkspace

Functions | [hide private]
construct_workspace(*args, **kwargs) | source code
get_workspace() | source code

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.workspace')`
| _workspace_ = ``[``]``